pub struct PropagateSet<C>{ /* private fields */ }Expand description
The set in which propagation systems are added. You can schedule your logic relative to this set.
This is used with propagation configured via the HierarchyPropagatePlugin. See its
documentation for details on how propagation is configured and behaves.