pub struct TransformGizmoRenderStep;Expand description
A System set that runs all systems needed to render the transform gizmo to the screen, used in the bevy_gizmos_render crate
This is defined here since it is used by many other
bevy crates to specify system orderings.
This is used for Bevy’s Transform Gizmo and any other gizmo that render similar to it.